@@ -2,7 +2,7 @@
  * addr_to_ifinet6:
  *  Function to format a given address to a Linux /proc/net/if_inet6 format
  *
- * Version:		$Id: addr2if_inet6.c,v 0.16 2001/03/13 $
+ * Version:		$Id: addr_to_ifinet6.c,v 1.1.1.1 2001/10/07 14:47:40 peter Exp $
  * 
  * Author:		Peter Bieringer <pb@bieringer.de>
  *
@@ -13,7 +13,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include "ipv6calc.h"
-#include "include/modifiedfromlinuxkernel/include/net/ipv6-split.h"
+#include "libipv6addr.h"
 
 void addr_to_ifinet6_printhelp() {
 	fprintf(stderr, " %s --addr_to_ifinet6 ipv6addr[/prefixlength]\n", PROGRAM_NAME);
@@ -35,15 +35,17 @@ void addr_to_ifinet6_printhelplong() {
 int addr_to_ifinet6(char *addrstring, char *resultstring) {
 	int retval = 1, result;
 	ipv6calc_ipv6addr ipv6addr; 
+	char tempstring[NI_MAXHOST];
 
-#ifdef DEBUG_addr_to_ifinet6
-	fprintf(stderr, "addr_to_ifinet6: got input: %s\n", addrstring);
-#endif
+	if (ipv6calc_debug & DEBUG_addr_to_ifinet6) {
+		fprintf(stderr, "addr_to_ifinet6: got input: %s\n", addrstring);
+	};
 
     result = addr_to_ipv6addrstruct(addrstring, resultstring, &ipv6addr);
-#ifdef DEBUG_addr_to_ifinet6
-    fprintf(stderr, "addr_to_ifinet6: result of 'addr_to_ipv6addrstruct': %d\n", result);
-#endif
+	
+	if (ipv6calc_debug & DEBUG_addr_to_ifinet6) {
+    	fprintf(stderr, "addr_to_ifinet6: result of 'addr_to_ipv6addrstruct': %d\n", result);
+	};
    
 	if ( result != 0 ) {
 		retval = 1;
@@ -51,15 +53,17 @@ int addr_to_ifinet6(char *addrstring, char *resultstring) {
 	};
 
 	/* print out array */	
+    sprintf(tempstring, "%08x%08x%08x%08x %02x",  ipv6addr_getdword(&ipv6addr, 0), ipv6addr_getdword(&ipv6addr, 1),  ipv6addr_getdword(&ipv6addr, 2),  ipv6addr_getdword(&ipv6addr, 3), ipv6addr.scope & IPV6_ADDR_SCOPE_MASK);
+	
 	if ( ipv6addr.flag_prefixuse == 1 ) {
-	    sprintf(resultstring, "%04x%04x%04x%04x%04x%04x%04x%04x %02x %02x", ipv6addr.addr6[0], ipv6addr.addr6[1],  ipv6addr.addr6[2],  ipv6addr.addr6[3],  ipv6addr.addr6[4],  ipv6addr.addr6[5],  ipv6addr.addr6[6],  ipv6addr.addr6[7],  ipv6addr.scope & IPV6_ADDR_SCOPE_MASK,  ipv6addr.prefixlength);
+	    sprintf(resultstring, "%s %02x", tempstring, ipv6addr.prefixlength);
 	} else {
-	    sprintf(resultstring, "%04x%04x%04x%04x%04x%04x%04x%04x %02x",  ipv6addr.addr6[0],  ipv6addr.addr6[1],  ipv6addr.addr6[2],  ipv6addr.addr6[3],  ipv6addr.addr6[4],  ipv6addr.addr6[5],  ipv6addr.addr6[6],  ipv6addr.addr6[7],  ipv6addr.scope & IPV6_ADDR_SCOPE_MASK);
+	    sprintf(resultstring, "%s", tempstring);
 	};
 
-#ifdef DEBUG_addr_to_if_inet6
-	fprintf(stderr, "addr_to_ifinet6: Print out: %s\n", resultstring);
-#endif
+	if (ipv6calc_debug & DEBUG_addr_to_ifinet6) {
+		fprintf(stderr, "addr_to_ifinet6: Print out: %s\n", resultstring);
+	};
 
 	retval = 0;
 	return (retval);
