@@ -3,7 +3,7 @@
  *  A function to format a given MAC address to a
  *   EUI-64 identifier
  *
- * Version:		$Id: mac_to_eui64.c,v 0.20 2001/04/08 $
+ * Version:		$Id: mac_to_eui64.c,v 1.1.1.1 2001/10/07 14:47:40 peter Exp $
  * 
  * Author:		Peter Bieringer <pb@bieringer.de>
  *
@@ -29,20 +29,21 @@ void mac_to_eui64_printhelplong() {
  * out: *resultstring = result
  * ret: ==0: ok, !=0: error
  */
+#define DEBUG_function_name "mac_to_eui64"
 int mac_to_eui64(char *addrstring, char *resultstring) {
 	int retval = 1, result;
 	ipv6calc_ipv6addr ipv6addr;
 	ipv6calc_macaddr macaddr;
 
-#ifdef DEBUG_mac_to_eui64
-	fprintf(stderr, "mac_to_eui64: Got input %s\n", addrstring);
-#endif
+	if ( ipv6calc_debug & DEBUG_mac_to_eui64 ) {
+		fprintf(stderr, "%s: Got input %s\n", DEBUG_function_name, addrstring);
+	};
 
 	result = mac_to_macaddrstruct(addrstring, resultstring, &macaddr);
 
-#ifdef DEBUG_mac_to_eui64
-	fprintf(stderr, "mac_to_eui64: result of 'mac_to_ipv6addrstruct: %d\n", result);
-#endif
+	if ( ipv6calc_debug & DEBUG_mac_to_eui64 ) {
+		fprintf(stderr, "%s: result of 'mac_to_ipv6addrstruct: %d\n", DEBUG_function_name, result);
+	};
 
 	if ( result != 0 ) {
 		retval = 1;
@@ -61,3 +62,4 @@ int mac_to_eui64(char *addrstring, char *resultstring) {
 	retval = 0;
 	return (retval);
 };
+#undef DEBUG_function_name
